// based on alternative-status-menu@gnome-shell-extensions.gcampax.github.com

const GLib = imports.gi.GLib;
const Lang = imports.lang;
const St = imports.gi.St;

const Main = imports.ui.main;
const PanelMenu = imports.ui.panelMenu;
const PopupMenu = imports.ui.popupMenu;
const GnomeSession = imports.misc.gnomeSession;
const UserMenu = imports.ui.userMenu;

const statusMenu = Main.panel._statusArea.userMenu;

const Gettext = imports.gettext.domain('gnome-shell-extensions');
const _ = Gettext.gettext;

///------------------------------------------------------------------///
function updateSuspend(object, pspec, item) {
    item.actor.visible = object.get_can_suspend();
}
function updateHibernate(object, pspec, item) {
    item.actor.visible = object.get_can_hibernate();
}

function onSuspendActivate(item) {
    Main.overview.hide();

    this._screenSaverProxy.LockRemote(Lang.bind(this, function() {
        this._upClient.suspend_sync(null);
    }));
}
function onHibernateActivate(item) {
    Main.overview.hide();

    this._screenSaverProxy.LockRemote(Lang.bind(this, function() {
        this._upClient.hibernate_sync(null);
    }));
}
///------------------------------------------------------------------///

function init(metadata) {
	imports.gettext.bindtextdomain('gnome-shell-extensions', GLib.build_filenamev([metadata.path, 'locale']));
}

function createPopUpMenu()
{	
	let item;
	
	item = new PopupMenu.PopupMenuItem(_("Lock Screen"));
	item.connect('activate', Lang.bind(statusMenu, statusMenu._onLockScreenActivate));
	this.menu.addMenuItem(item);
	this._lockScreenItem = item;
	
	item = new PopupMenu.PopupMenuItem(_("Switch User"));
	item.connect('activate', Lang.bind(statusMenu, statusMenu._onLoginScreenActivate));
	this.menu.addMenuItem(item);
	this._loginScreenItem = item;

	item = new PopupMenu.PopupMenuItem(_("Log Out..."));
	item.connect('activate', Lang.bind(statusMenu, statusMenu._onQuitSessionActivate));
	this.menu.addMenuItem(item);
	this._logoutItem = item;

	item = new PopupMenu.PopupSeparatorMenuItem();
	this.menu.addMenuItem(item);

	item = new PopupMenu.PopupMenuItem(_("Suspend"));
	item.connect('activate', Lang.bind(statusMenu, onSuspendActivate));
	statusMenu._upClient.connect('notify::can-suspend', Lang.bind(statusMenu, updateSuspend, item));
	updateSuspend(statusMenu._upClient, null, item);
	this.menu.addMenuItem(item);

	item = new PopupMenu.PopupMenuItem(_("Hibernate"));
	item.connect('activate', Lang.bind(statusMenu, onHibernateActivate));
	statusMenu._upClient.connect('notify::can-hibernate', Lang.bind(statusMenu, updateHibernate, item));
	updateHibernate(statusMenu._upClient, null, item);
	this.menu.addMenuItem(item);

	item = new PopupMenu.PopupMenuItem(_("Power Off..."));
	item.connect('activate', Lang.bind(statusMenu, function() {statusMenu._session.ShutdownRemote();}));
	this.menu.addMenuItem(item);
}

function enable() {
	this.button = new PanelMenu.SystemStatusButton('system-shutdown');
	createPopUpMenu.call(this.button);
	
	Main.panel.addToStatusArea('quitButton', this.button,Main.panel._status_area_order.length);
	
	Main.panel._statusArea['userMenu'].actor.hide();
}

function disable() {
	this.button.destroy();
	this.button = null;
	
	Main.panel._statusArea['userMenu'].actor.show();
}
